@@ -30,12 +30,12 @@ setConstructorS3("SnpInformation", function(...) {
 
 setMethodS3("as.character", "SnpInformation", function(x, ...) {
   # To please R CMD check
-  this <- x;
+  this <- x
 
-  s <- NextMethod("as.character");
-  s <- c(s, sprintf("Chip type: %s", getChipType(this)));
-  s <- c(s, sprintf("Number of enzymes: %s", nbrOfEnzymes(this)));
-  s;
+  s <- NextMethod("as.character")
+  s <- c(s, sprintf("Chip type: %s", getChipType(this)))
+  s <- c(s, sprintf("Number of enzymes: %s", nbrOfEnzymes(this)))
+  s
 }, protected=TRUE)
 
 
@@ -65,7 +65,7 @@ setMethodS3("as.character", "SnpInformation", function(x, ...) {
 # }
 #*/###########################################################################
 setMethodS3("verify", "SnpInformation", function(this, ...) {
-  TRUE;
+  TRUE
 }, protected=TRUE)
 
 
@@ -96,19 +96,19 @@ setMethodS3("verify", "SnpInformation", function(this, ...) {
 setMethodS3("getChipType", "SnpInformation", function(this, ...) {
   # Infer chip type from the first parent directory that has the same name
   # as the chip type of an existing CDF file.
-  pathname <- getPathname(this);
-  lastPath <- pathname;
+  pathname <- getPathname(this)
+  lastPath <- pathname
   while (TRUE) {
-    path <- dirname(lastPath);
+    path <- dirname(lastPath)
     if (path == lastPath)
-      break;
-    chipType <- basename(path);
-    dummy <- AffymetrixCdfFile$findByChipType(chipType);
+      break
+    chipType <- basename(path)
+    dummy <- AffymetrixCdfFile$findByChipType(chipType)
     if (!is.null(dummy))
       return(chipType)
-    lastPath <- path;
+    lastPath <- path
   }
-  throw("Failed to infer the chip type from the pathname of the SNP information file: ", pathname);
+  throw("Failed to infer the chip type from the pathname of the SNP information file: ", pathname)
 })
 
 
@@ -138,7 +138,7 @@ setMethodS3("getChipType", "SnpInformation", function(this, ...) {
 # }
 #*/###########################################################################
 setMethodS3("fromCdf", "SnpInformation", function(static, cdf, ...) {
-  byChipType(static, chipType=getChipType(cdf), nbrOfUnits=nbrOfUnits(cdf), ...);
+  byChipType(static, chipType=getChipType(cdf), nbrOfUnits=nbrOfUnits(cdf), ...)
 }, static=TRUE, protected=TRUE)
 
 
@@ -168,22 +168,22 @@ setMethodS3("fromCdf", "SnpInformation", function(static, cdf, ...) {
 #   @seeclass
 # }
 #*/###########################################################################
-setMethodS3("byChipType", "SnpInformation", abstract=TRUE);
+setMethodS3("byChipType", "SnpInformation", abstract=TRUE)
 
 
 setMethodS3("fromDataSet", "SnpInformation", function(static, dataSet, ...) {
-  chipType <- getChipType(dataSet);
-  byChipType(static, chipType=chipType, ...);
+  chipType <- getChipType(dataSet)
+  byChipType(static, chipType=chipType, ...)
 }, static=TRUE, protected=TRUE)
 
 
 
 setMethodS3("isCompatibleWithCdf", "SnpInformation", function(this, cdf, ...) {
   # Argument 'cdf':
-  cdf <- Arguments$getInstanceOf(cdf, "AffymetrixCdfFile");
+  cdf <- Arguments$getInstanceOf(cdf, "AffymetrixCdfFile")
 
   # By default, be naive and always return FALSE.
-  TRUE;
+  TRUE
 }, protected=TRUE)
 
 
@@ -220,197 +220,179 @@ setMethodS3("isCompatibleWithCdf", "SnpInformation", function(this, cdf, ...) {
 #*/###########################################################################
 setMethodS3("getData", "SnpInformation", function(this, units=NULL, fields=c("fragmentLength", "start", "stop"), orderBy=NULL, ..., force=FALSE, verbose=FALSE) {
   # Argument 'verbose':
-  verbose <- Arguments$getVerbose(verbose);
+  verbose <- Arguments$getVerbose(verbose)
 
-  data <- this$.data;
+  data <- this$.data
   if (force || is.null(data)) {
-    verbose && enter(verbose, "Retrieving SNP information from file");
+    verbose && enter(verbose, "Retrieving SNP information from file")
 
     # Read the unit names from the corresponding CDF file
-    verbose && enter(verbose, "Reading unit names from CDF file");
-    chipType <- getChipType(this);
-    cdfFile <- AffymetrixCdfFile$findByChipType(chipType);
+    verbose && enter(verbose, "Reading unit names from CDF file")
+    chipType <- getChipType(this)
+    cdfFile <- AffymetrixCdfFile$findByChipType(chipType)
     if (is.null(cdfFile))
-      throw("Could not located CDF file: ", chipType);
-    targetUnitNames <- .readCdfUnitNames(cdfFile);
-    verbose && exit(verbose);
+      throw("Could not located CDF file: ", chipType)
+    targetUnitNames <- .readCdfUnitNames(cdfFile)
+    verbose && exit(verbose)
 
     # Now read the SNP information data
-    verbose && enter(verbose, "Reading SNP information data");
-    data <- readDataFrame(this, verbose=less(verbose));
+    verbose && enter(verbose, "Reading SNP information data")
+    data <- readDataFrame(this, verbose=less(verbose))
     # Garbage collect
-    gc <- gc();
-    verbose && print(verbose, gc);
-    verbose && exit(verbose);
+    gc <- gc()
+    verbose && print(verbose, gc)
+    verbose && exit(verbose)
 
-    verbose && enter(verbose, "Splitting up the fragment length, start & stop details");
-    cc <- which("fragmentLengthStartStop" == colnames(data));
-    lss <- data[,cc,drop=TRUE];
-    nas <- ((lss == "---") | (lss == ""));
-    lss[nas] <- "-//-//-";
-    lss <- strsplit(lss, split="//");
-    len <- sapply(lss, FUN=length);
+    verbose && enter(verbose, "Splitting up the fragment length, start & stop details")
+    cc <- which("fragmentLengthStartStop" == colnames(data))
+    lss <- data[,cc,drop=TRUE]
+    nas <- ((lss == "---") | (lss == ""))
+    lss[nas] <- "-//-//-"
+    lss <- strsplit(lss, split="//")
+    len <- sapply(lss, FUN=length)
     if (any(len != 3)) {
-      ulen <- unique(len);
+      ulen <- unique(len)
       throw("Internal error: Unrecognized length of FLSS: ",
-                                           paste(ulen, collapse=", "));
+                                           paste(ulen, collapse=", "))
     }
-    lss <- unlist(lss, use.names=FALSE);
-    lss <- as.integer(lss);
-    lss <- matrix(lss, ncol=3, byrow=TRUE);
-    rownames(lss) <- 1:nrow(lss);
-    colnames(lss) <- c("fragmentLength", "start", "stop");
-    data <- cbind(data[,-cc,drop=FALSE], lss);
+    lss <- unlist(lss, use.names=FALSE)
+    lss <- as.integer(lss)
+    lss <- matrix(lss, ncol=3, byrow=TRUE)
+    rownames(lss) <- 1:nrow(lss)
+    colnames(lss) <- c("fragmentLength", "start", "stop")
+    data <- cbind(data[,-cc,drop=FALSE], lss)
     # Not needed anymore
-    lss <- NULL;
-    verbose && exit(verbose);
+    lss <- NULL
+    verbose && exit(verbose)
 
-    verbose && enter(verbose, "Reordering units according to the CDF file");
-    idxs <- match(targetUnitNames, data[,1]);
-    data <- data[idxs,];
-    rownames(data) <- 1:nrow(data);
-#    data <- data[idxs,-1];
-    verbose && exit(verbose);
+    verbose && enter(verbose, "Reordering units according to the CDF file")
+    idxs <- match(targetUnitNames, data[,1])
+    data <- data[idxs,]
+    rownames(data) <- 1:nrow(data)
+#    data <- data[idxs,-1]
+    verbose && exit(verbose)
     # Store in cache
-    this$.data <- data;
+    this$.data <- data
 
-    verbose && exit(verbose);
+    verbose && exit(verbose)
   }
 
   # Subset by unit?
   if (!is.null(units)) {
     # Map the unit indicies to the row names
-    rr <- match(units, rownames(data));
-    data <- data[rr,,drop=TRUE];
+    rr <- match(units, rownames(data))
+    data <- data[rr,,drop=TRUE]
   }
 
   # Stratify by field values?
-  args <- list(...);
+  args <- list(...)
   if (length(args) > 0) {
     for (key in names(args)) {
       # Get the values to be stratified upon.
-      values <- data[,key];
+      values <- data[,key]
 
       # Get the test (value or function)
-      test <- args[[key]];
-      test <- na.omit(test);
+      test <- args[[key]]
+      test <- na.omit(test)
       if (is.function(test)) {
-        keep <- test(values);
+        keep <- test(values)
       } else {
-        keep <- (values == test);
+        keep <- (values == test)
       }
-      data <- data[keep,,drop=FALSE];
+      data <- data[keep,,drop=FALSE]
     }
     # Not needed anymore
-    keep <- NULL;
+    keep <- NULL
   }
 
   # Reorder?
   if (!is.null(orderBy)) {
-    o <- do.call(order, args=as.list(data[,orderBy]));
-    data <- data[o,,drop=FALSE];
+    o <- do.call(order, args=as.list(data[,orderBy]))
+    data <- data[o,,drop=FALSE]
     # Not needed anymore
-    o <- NULL;
+    o <- NULL
   }
 
   # Extract a subset of fields?
   if (!is.null(fields))
-    data <- data[,fields, drop=FALSE];
+    data <- data[,fields, drop=FALSE]
 
-  data;
+  data
 })
 
 
 setMethodS3("nbrOfUnits", "SnpInformation", function(this, ...) {
-  data <- getData(this, fields=1);
-  nrow(data);
+  data <- getData(this, fields=1)
+  nrow(data)
 })
 
 setMethodS3("getFields", "SnpInformation", function(this, ...) {
-  data <- getData(this);
-  colnames(data);
+  data <- getData(this)
+  colnames(data)
 }, protected=TRUE)
 
 
 
-setMethodS3("readDataFrame", "SnpInformation", abstract=TRUE);
+setMethodS3("readDataFrame", "SnpInformation", abstract=TRUE)
 
 
 setMethodS3("readTableInternal", "SnpInformation", function(this, pathname, colClasses=NULL, ..., include=NULL, exclude=NULL, verbose=FALSE) {
   # Argument 'verbose':
-  verbose <- Arguments$getVerbose(verbose);
+  verbose <- Arguments$getVerbose(verbose)
 
-  verbose && enter(verbose, "Reading tabular data from file");
-  pathname <- getPathname(this);
-  verbose && cat(verbose, "Pathname: ", pathname);
+  verbose && enter(verbose, "Reading tabular data from file")
+  pathname <- getPathname(this)
+  verbose && cat(verbose, "Pathname: ", pathname)
 
-  verbose && cat(verbose, "Argument 'include': ", paste(include, collapse=", "));
-  verbose && cat(verbose, "Argument 'exclude': ", paste(exclude, collapse=", "));
-  exclude <- setdiff(exclude, include);
-  verbose && cat(verbose, "exclude\\include: ", paste(exclude, collapse=", "));
-  colClasses[names(colClasses) %in% exclude] <- "NULL";
-  toRead <- names(colClasses)[colClasses != "NULL"];
-  verbose && cat(verbose, "Columns to be read: ", paste(toRead, collapse=", "));
+  verbose && cat(verbose, "Argument 'include': ", paste(include, collapse=", "))
+  verbose && cat(verbose, "Argument 'exclude': ", paste(exclude, collapse=", "))
+  exclude <- setdiff(exclude, include)
+  verbose && cat(verbose, "exclude\\include: ", paste(exclude, collapse=", "))
+  colClasses[names(colClasses) %in% exclude] <- "NULL"
+  toRead <- names(colClasses)[colClasses != "NULL"]
+  verbose && cat(verbose, "Columns to be read: ", paste(toRead, collapse=", "))
 
-  df <- readTable(pathname, colClasses=colClasses, header=TRUE, sep="\t", ..., verbose=less(verbose));
+  df <- readTable(pathname, colClasses=colClasses, header=TRUE, sep="\t", ..., verbose=less(verbose))
 
-  colnames(df) <- toCamelCase(colnames(df));
-  verbose && exit(verbose);
+  colnames(df) <- toCamelCase(colnames(df))
+  verbose && exit(verbose)
 
-  df;
+  df
 }, private=TRUE)
 
 
 setMethodS3("nbrOfEnzymes", "SnpInformation", function(this, ...) {
-  as.integer(1);
+  as.integer(1)
 })
 
 setMethodS3("getFragmentLengths", "SnpInformation", function(this, enzymes=seq_len(nbrOfEnzymes(this)), ...) {
-  data <- getData(this, ..., fields="fragmentLength");
-  fl <- data[,enzymes,drop=FALSE];
-  fl <- as.matrix(fl);
-  dim <- dim(fl);
-  fl <- as.integer(fl);
-  dim(fl) <- dim;
-  fl;
+  data <- getData(this, ..., fields="fragmentLength")
+  fl <- data[,enzymes,drop=FALSE]
+  fl <- as.matrix(fl)
+  dim <- dim(fl)
+  fl <- as.integer(fl)
+  dim(fl) <- dim
+  fl
 })
 
 
 setMethodS3("getFragmentStarts", "SnpInformation", function(this, enzymes=seq_len(nbrOfEnzymes(this)), ...) {
-  data <- getData(this, ..., fields="start");
-  fl <- data[,enzymes,drop=FALSE];
-  fl <- as.matrix(fl);
-  dim <- dim(fl);
-  fl <- as.integer(fl);
-  dim(fl) <- dim;
-  fl;
+  data <- getData(this, ..., fields="start")
+  fl <- data[,enzymes,drop=FALSE]
+  fl <- as.matrix(fl)
+  dim <- dim(fl)
+  fl <- as.integer(fl)
+  dim(fl) <- dim
+  fl
 })
 
 
 setMethodS3("getFragmentStops", "SnpInformation", function(this, enzymes=seq_len(nbrOfEnzymes(this)), ...) {
-  data <- getData(this, ..., fields="stop");
-  fl <- data[,enzymes,drop=FALSE];
-  fl <- as.matrix(fl);
-  dim <- dim(fl);
-  fl <- as.integer(fl);
-  dim(fl) <- dim;
-  fl;
+  data <- getData(this, ..., fields="stop")
+  fl <- data[,enzymes,drop=FALSE]
+  fl <- as.matrix(fl)
+  dim <- dim(fl)
+  fl <- as.integer(fl)
+  dim(fl) <- dim
+  fl
 })
-
-
-
-############################################################################
-# HISTORY:
-# 2008-04-14
-# o Renamed readData() to readDataFrame() for SnpInformation.
-# 2007-11-19
-# o Now getFragmentLength/Starts/Stops() of SnpInformation return a matrix
-#   where each column correspond to an enzyme. This is was added because
-#   the new SNP chips have two enzymes. Added nbrOfEnzymes().
-# 2007-01-22
-# o BUG FIX: getData() did not support the dChip SNP information file for
-#   the Mapping10K_Xba142 chip type, because yet again it used a slightly
-#   different format compared with the 100K and the 500K files.
-# 2006-09-17
-# o Created from GenomeInformation.R.
-############################################################################
