@@ -27,12 +27,12 @@ setConstructorS3("TransformReport", function(inSet=NULL, outSet=NULL, ...) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Argument 'inSet':
   if (!is.null(inSet)) {
-    inSet <- Arguments$getInstanceOf(inSet, "AffymetrixCelSet");
-    outSet <- Arguments$getInstanceOf(outSet, "AffymetrixCelSet");
+    inSet <- Arguments$getInstanceOf(inSet, "AffymetrixCelSet")
+    outSet <- Arguments$getInstanceOf(outSet, "AffymetrixCelSet")
 
     # Check for compatibility
 #    if (!equals(getCdf(inSet), getCdf(outSet))) {
-#      throw("Argument 'inSet' and 'outSet' have incompatible CDFs.");
+#      throw("Argument 'inSet' and 'outSet' have incompatible CDFs.")
 #    }
   }
 
@@ -46,24 +46,24 @@ setConstructorS3("TransformReport", function(inSet=NULL, outSet=NULL, ...) {
 
 
 setMethodS3("getRootPath", "TransformReport", function(this, ...) {
-  "reports";
+  "reports"
 }, private=TRUE)
 
 
 setMethodS3("as.character", "TransformReport", function(x, ...) {
   # To please R CMD check
-  this <- x;
+  this <- x
 
-  s <- sprintf("%s:", class(this)[1]);
-  ds <- getInputDataSet(this);
-  s <- c(s, sprintf("Input data set: %s", getFullName(ds)));
-  ds <- getOutputDataSet(this);
-  s <- c(s, sprintf("Output data set: %s", getFullName(ds)));
+  s <- sprintf("%s:", class(this)[1])
+  ds <- getInputDataSet(this)
+  s <- c(s, sprintf("Input data set: %s", getFullName(ds)))
+  ds <- getOutputDataSet(this)
+  s <- c(s, sprintf("Output data set: %s", getFullName(ds)))
   s <- c(s, sprintf("Number of arrays: %d (%s)",
            length(ds), hsize(getFileSize(ds), digits = 2L, standard = "IEC")))
-  s <- c(s, sprintf("Chip type: %s", getChipType(getCdf(ds))));
+  s <- c(s, sprintf("Chip type: %s", getChipType(getCdf(ds))))
 
-  GenericSummary(s);
+  GenericSummary(s)
 }, protected=TRUE)
 
 
@@ -92,23 +92,23 @@ setMethodS3("as.character", "TransformReport", function(x, ...) {
 # }
 #*/###########################################################################
 setMethodS3("getName", "TransformReport", function(this, ...) {
-  name <- getAlias(this);
+  name <- getAlias(this)
   if (is.null(name)) {
-    ds <- getOutputDataSet(this);
-    name <- getName(ds);
+    ds <- getOutputDataSet(this)
+    name <- getName(ds)
   }
-  name;
+  name
 })
 
 setMethodS3("getAlias", "TransformReport", function(this, ...) {
-  this$.alias;
+  this$.alias
 }, protected=TRUE)
 
 setMethodS3("setAlias", "TransformReport", function(this, alias, ...) {
   if (!is.null(alias)) {
-    alias <- Arguments$getCharacter(alias, nchar=c(1,Inf), length=c(1,1));
+    alias <- Arguments$getCharacter(alias, nchar=c(1,Inf), length=c(1,1))
   }
-  this$.alias <- alias;
+  this$.alias <- alias
 }, protected=TRUE)
 
 
@@ -137,22 +137,22 @@ setMethodS3("setAlias", "TransformReport", function(this, alias, ...) {
 # }
 #*/###########################################################################
 setMethodS3("getTags", "TransformReport", function(this, collapse=NULL, ...) {
-  tags <- this$.tags;
+  tags <- this$.tags
 
-  ds <- getOutputDataSet(this);
-  tags <- getTags(ds, collapse=collapse);
+  ds <- getOutputDataSet(this)
+  tags <- getTags(ds, collapse=collapse)
 
   # Collapsed or split?
   if (!is.null(collapse)) {
-    tags <- paste(tags, collapse=collapse);
+    tags <- paste(tags, collapse=collapse)
   } else {
-    tags <- unlist(strsplit(tags, split=","));
+    tags <- unlist(strsplit(tags, split=","))
   }
 
   if (length(tags) == 0)
-    tags <- NULL;
+    tags <- NULL
 
-  tags;
+  tags
 })
 
 
@@ -181,11 +181,11 @@ setMethodS3("getTags", "TransformReport", function(this, collapse=NULL, ...) {
 # }
 #*/###########################################################################
 setMethodS3("getFullName", "TransformReport", function(this, ...) {
-  name <- getName(this);
-  tags <- getTags(this);
-  fullname <- paste(c(name, tags), collapse=",");
-  fullname <- gsub("[,]$", "", fullname);
-  fullname;
+  name <- getName(this)
+  tags <- getTags(this)
+  fullname <- paste(c(name, tags), collapse=",")
+  fullname <- gsub("[,]$", "", fullname)
+  fullname
 })
 
 
@@ -217,24 +217,24 @@ setMethodS3("getPath", "TransformReport", function(this, ...) {
   # Create the (sub-)directory tree for the data set
 
   # Root path
-  rootPath <- getRootPath(this);
+  rootPath <- getRootPath(this)
 
   # Full name
-  fullname <- getFullName(this);
+  fullname <- getFullName(this)
 
   # Chip type
-  ds <- getOutputDataSet(this);
-  unf <- getUnitNamesFile(ds);
-  chipType <- getChipType(unf, fullname=FALSE);
+  ds <- getOutputDataSet(this)
+  unf <- getUnitNamesFile(ds)
+  chipType <- getChipType(unf, fullname=FALSE)
 
   # Image set
-  set <- "transform";
+  set <- "transform"
 
   # The full path
-  path <- filePath(rootPath, fullname, chipType, set);
-  path <- Arguments$getWritablePath(path);
+  path <- filePath(rootPath, fullname, chipType, set)
+  path <- Arguments$getWritablePath(path)
 
-  path;
+  path
 })
 
 
@@ -263,7 +263,7 @@ setMethodS3("getPath", "TransformReport", function(this, ...) {
 # }
 #*/###########################################################################
 setMethodS3("getInputDataSet", "TransformReport", function(this, ...) {
-  this$.inSet;
+  this$.inSet
 })
 
 
@@ -292,247 +292,227 @@ setMethodS3("getInputDataSet", "TransformReport", function(this, ...) {
 # }
 #*/###########################################################################
 setMethodS3("getOutputDataSet", "TransformReport", function(this, ...) {
-  this$.outSet;
+  this$.outSet
 })
 
 
 setMethodS3("getCdf", "TransformReport", function(this, ...) {
-  getCdf(getOutputDataSet(this));
+  getCdf(getOutputDataSet(this))
 })
 
 
 setMethodS3("getUnitNamesFile", "TransformReport", function(this, ...) {
-  dsOut <- getOutputDataSet(this);
-  getUnitNamesFile(dsOut);
+  dsOut <- getOutputDataSet(this)
+  getUnitNamesFile(dsOut)
 })
 
 setMethodS3("getUnitTypesFile", "TransformReport", function(this, ...) {
-  dsOut <- getOutputDataSet(this);
-  getUnitTypesFile(dsOut);
+  dsOut <- getOutputDataSet(this)
+  getUnitTypesFile(dsOut)
 })
 
 
 setMethodS3("nbrOfArrays", "TransformReport", function(this, ...) {
-  length(getOutputDataSet(this));
+  length(getOutputDataSet(this))
 })
 
 setMethodS3("seq", "TransformReport", function(this, ...) {
-  seq_len(length(this));
+  seq_len(length(this))
 })
 
 
 setMethodS3("getYY", "TransformReport", function(this, array, transform=NULL, subset=1/8, field="intensities", ...) {
-  inSet <- getInputDataSet(this);
+  inSet <- getInputDataSet(this)
 
-  cdf <- getCdf(inSet);
+  cdf <- getCdf(inSet)
   if (length(subset) == 1) {
-    indices <- seq(from=1, to=nbrOfCells(cdf), length=subset*nbrOfCells(cdf));
-    indices <- as.integer(indices);
+    indices <- seq(from=1, to=nbrOfCells(cdf), length=subset*nbrOfCells(cdf))
+    indices <- as.integer(indices)
   } else if (length(subset) > 1) {
-    indices <- Arguments$getIndices(subset, max=nbrOfCells(cdf));
+    indices <- Arguments$getIndices(subset, max=nbrOfCells(cdf))
   } else {
-    indices <- subset;
+    indices <- subset
   }
 
-  outSet <- getOutputDataSet(this);
-  df1 <- inSet[[array]];
-  df2 <- outSet[[array]];
+  outSet <- getOutputDataSet(this)
+  df1 <- inSet[[array]]
+  df2 <- outSet[[array]]
   res <- list(
     array = array,
     y1 = getData(df1, indices=indices, ..., fields=field)[[field]],
     y2 = getData(df2, indices=indices, ..., fields=field)[[field]]
-  );
+  )
 
   if (!is.null(transform)) {
-    res$y1 <- transform(res$y1);
-    res$y2 <- transform(res$y2);
+    res$y1 <- transform(res$y1)
+    res$y2 <- transform(res$y2)
   }
 
-  res;
+  res
 })
 
 
 
 setMethodS3("plotXYCurve", "TransformReport", function(this, arrays=seq_along(this), lwd=2, col=arrays, xlim=c(0,65535), xlab=expression(y[1]), ylab=expression(y[2]), main=NULL, ..., add=FALSE, verbose=FALSE) {
 
-  nbrOfArrays <- length(this);
+  nbrOfArrays <- length(this)
   if (is.null(col)) {
-    col <- seq_len(nbrOfArrays);
+    col <- seq_len(nbrOfArrays)
   } else {
-    col <- rep(col, length.out=nbrOfArrays);
+    col <- rep(col, length.out=nbrOfArrays)
   }
 
-  outSet <- getOutputDataSet(this);
-  unf <- getUnitNamesFile(this);
-  chipType <- getChipType(unf);
+  outSet <- getOutputDataSet(this)
+  unf <- getUnitNamesFile(this)
+  chipType <- getChipType(unf)
   for (kk in seq_along(arrays)) {
-    array <- arrays[kk];
+    array <- arrays[kk]
 
-    df <- outSet[[array]];
-    name <- getName(df);
+    df <- outSet[[array]]
+    name <- getName(df)
 
-    verbose && enter(verbose, sprintf("Array #%d ('%s')", kk, name));
+    verbose && enter(verbose, sprintf("Array #%d ('%s')", kk, name))
 
-    verbose && enter(verbose, "Retrieving data");
+    verbose && enter(verbose, "Retrieving data")
     suppressWarnings({
-      yy <- getYY(this, array=array, ...);
+      yy <- getYY(this, array=array, ...)
     })
-    verbose && str(verbose, yy);
-    verbose && exit(verbose);
+    verbose && str(verbose, yy)
+    verbose && exit(verbose)
 
     if (is.null(main))
-      main <- name;
+      main <- name
 
-    verbose && enter(verbose, "Plotting smooth (X,Y) curve");
+    verbose && enter(verbose, "Plotting smooth (X,Y) curve")
     suppressWarnings({
-      fit <- plotXYCurve(yy$y1, yy$y2, lwd=lwd, col=col[kk], xlim=xlim, xlab=xlab, ylab=ylab, ..., add=add);
+      fit <- plotXYCurve(yy$y1, yy$y2, lwd=lwd, col=col[kk], xlim=xlim, xlab=xlab, ylab=ylab, ..., add=add)
     })
-    verbose && exit(verbose);
+    verbose && exit(verbose)
 
     if (!add)
-      stextChipType(chipType, line=-1);
+      stextChipType(chipType, line=-1)
 
     if (length(arrays) == 1)
-      stextSize(df, size=length(yy$y1));
+      stextSize(df, size=length(yy$y1))
 
-    add <- TRUE;
+    add <- TRUE
 
     # Not needed anymore
-    yy <- NULL;
+    yy <- NULL
 
     # Garbage collect
-    gc();
+    gc()
 
-    verbose && exit(verbose);
+    verbose && exit(verbose)
   } # for (array in ...)
 
-  box();
+  box()
 
-  invisible();
+  invisible()
 })
 
 
 setMethodS3("plotXYCurveLog2", "TransformReport", function(this, xlim=c(0,16), xlab=expression(log[2](y[1])), ylab=expression(log[2]*(y[2])), ...) {
-  plotXYCurve(this, transform=log2, xlim=xlim, xlab=xlab, ylab=ylab, ...);
+  plotXYCurve(this, transform=log2, xlim=xlim, xlab=xlab, ylab=ylab, ...)
 })
 
 
 
 setMethodS3("writeImages", "TransformReport", function(this, path=NULL, width=800, height=width, ..., skip=TRUE, verbose=FALSE) {
-  pngDev <- findPngDevice(transparent=FALSE);
+  pngDev <- findPngDevice(transparent=FALSE)
 
-  unf <- getUnitNamesFile(this);
-  chipType <- getChipType(unf, fullname=FALSE);
-  rootPath <- getRootPath(this);
-  name <- getName(this);
-  tags <- getTags(this);
-  tags <- paste(tags, collapse=",");
-  set <- "transform";
-  path <- file.path(rootPath, name, tags, chipType, set);
-  path <- Arguments$getWritablePath(path);
+  unf <- getUnitNamesFile(this)
+  chipType <- getChipType(unf, fullname=FALSE)
+  rootPath <- getRootPath(this)
+  name <- getName(this)
+  tags <- getTags(this)
+  tags <- paste(tags, collapse=",")
+  set <- "transform"
+  path <- file.path(rootPath, name, tags, chipType, set)
+  path <- Arguments$getWritablePath(path)
 
-  outSet <- getOutputDataSet(this);
-  nbrOfArrays <- length(outSet);
+  outSet <- getOutputDataSet(this)
+  nbrOfArrays <- length(outSet)
 
-  verbose && enter(verbose, "Writing images for ", nbrOfArrays, " arrays");
+  verbose && enter(verbose, "Writing images for ", nbrOfArrays, " arrays")
 
-  verbose && printf(verbose, "Image dimension: %.0fx%.0f\n", width, height);
+  verbose && printf(verbose, "Image dimension: %.0fx%.0f\n", width, height)
 
   for (kk in seq_len(nbrOfArrays)) {
-    df <- outSet[[kk]];
-    fullname <- getFullName(df);
-    verbose && enter(verbose, "Output CEL file: ", fullname);
+    df <- outSet[[kk]]
+    fullname <- getFullName(df)
+    verbose && enter(verbose, "Output CEL file: ", fullname)
 
     # Plot (log2(y),log2(y))
-    tags <- c("YvY,log2");
-    imgname <- paste(c(fullname, tags), collapse=",");
-    filename <- sprintf("%s.png", imgname);
-    pathname <- file.path(path, filename);
+    tags <- c("YvY,log2")
+    imgname <- paste(c(fullname, tags), collapse=",")
+    filename <- sprintf("%s.png", imgname)
+    pathname <- file.path(path, filename)
 
-    verbose && cat(verbose, "Image pathname: ", pathname);
+    verbose && cat(verbose, "Image pathname: ", pathname)
     if (!skip || !isFile(pathname)) {
-      pngDev(pathname, width=width, height=height);
+      pngDev(pathname, width=width, height=height)
       tryCatch({
-        plotXYCurveLog2(this, array=kk, dcol="#cccccc", ...);
+        plotXYCurveLog2(this, array=kk, dcol="#cccccc", ...)
       }, finally = {
-        devDone();
+        devDone()
       })
     }
 
     # Garbage collection
     if (kk %% 10 == 0)
-      verbose && print(verbose, gc());
+      verbose && print(verbose, gc())
 
-    verbose && exit(verbose);
+    verbose && exit(verbose)
   }
 
   # Garbage collection
-  verbose && print(verbose, gc());
+  verbose && print(verbose, gc())
 
-  verbose && exit(verbose);
+  verbose && exit(verbose)
 })
 
 
 
 
 setMethodS3("writeImageCombined", "TransformReport", function(this, path=NULL, width=800, height=width, ..., skip=TRUE, verbose=FALSE) {
-  pngDev <- findPngDevice(transparent=FALSE);
+  pngDev <- findPngDevice(transparent=FALSE)
 
-  unf <- getUnitNamesFile(this);
-  chipType <- getChipType(unf, fullname=FALSE);
-  rootPath <- getRootPath(this);
-  name <- getName(this);
-  tags <- getTags(this);
-  tags <- paste(tags, collapse=",");
-  set <- "transform";
-  path <- file.path(rootPath, name, tags, chipType, set);
-  path <- Arguments$getWritablePath(path);
+  unf <- getUnitNamesFile(this)
+  chipType <- getChipType(unf, fullname=FALSE)
+  rootPath <- getRootPath(this)
+  name <- getName(this)
+  tags <- getTags(this)
+  tags <- paste(tags, collapse=",")
+  set <- "transform"
+  path <- file.path(rootPath, name, tags, chipType, set)
+  path <- Arguments$getWritablePath(path)
 
-  outSet <- getOutputDataSet(this);
-  nbrOfArrays <- length(outSet);
+  outSet <- getOutputDataSet(this)
+  nbrOfArrays <- length(outSet)
 
-  verbose && enter(verbose, "Writing combined image for ", nbrOfArrays, " arrays");
+  verbose && enter(verbose, "Writing combined image for ", nbrOfArrays, " arrays")
 
-  verbose && printf(verbose, "Image dimension: %.0fx%.0f\n", width, height);
+  verbose && printf(verbose, "Image dimension: %.0fx%.0f\n", width, height)
 
   # Plot (log2(y),log2(y))
-  tags <- c("YvY,log2");
-  imgname <- paste(c("all", tags), collapse=",");
-  filename <- sprintf("%s.png", imgname);
-  pathname <- file.path(path, filename);
+  tags <- c("YvY,log2")
+  imgname <- paste(c("all", tags), collapse=",")
+  filename <- sprintf("%s.png", imgname)
+  pathname <- file.path(path, filename)
 
-  verbose && cat(verbose, "Image pathname: ", pathname);
+  verbose && cat(verbose, "Image pathname: ", pathname)
   if (!skip || !isFile(pathname)) {
-    pngDev(pathname, width=width, height=height);
+    pngDev(pathname, width=width, height=height)
     tryCatch({
-      plotXYCurveLog2(this, ..., verbose=less(verbose));
+      plotXYCurveLog2(this, ..., verbose=less(verbose))
     }, finally = {
-      devDone();
+      devDone()
     })
   }
 
   # Garbage collection
-  verbose && print(verbose, gc());
+  verbose && print(verbose, gc())
 
-  verbose && exit(verbose);
+  verbose && exit(verbose)
 })
-
-
-
-
-############################################################################
-# HISTORY:
-# 2011-11-07
-# o Replaced dev.off() with devDone().
-# 2009-07-08
-# o Added getUnitTypesFile() for TransformReport.
-# 2008-05-18
-# o Made class less platform specific by utilizing UnitNamesFile interface.
-# 2007-03-24
-# o BUG FIX: getPath() created the root path before trying to expand
-#   Windows shortcuts.
-# 2007-02-06
-# o Updated the path to <rootPath>/<dataSetName>/<tags>/<chipType>/<set>/.
-# 2007-02-04
-# o Created.
-############################################################################
