@@ -80,7 +80,7 @@ str(units);
 # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
 srcFileTags <- list();
 srcFiles <- list(cdf, csv);
-for (kk in seq(along=srcFiles)) {
+for (kk in seq_along(srcFiles)) {
   srcFile <- srcFiles[[kk]];
   tags <- list(
     filename=getFilename(srcFile), 
@@ -97,7 +97,7 @@ footer$createdBy = list(
   fullname = fullname, 
   email = email
 );
-names(srcFileTags) <- sprintf("srcFile%d", seq(along=srcFileTags));
+names(srcFileTags) <- sprintf("srcFile%d", seq_along(srcFileTags));
 footer$srcFiles <- srcFileTags;
 writeFooter(ufl, footer);
 
